@@ -23,7 +23,7 @@ class PostgresqlHelper(RelationalDbHelper):
         :param param:
         :return:
         """
-        async with self.pool.connection() as conn:
+        async with self.pool.acquire() as conn:
             async with conn.cursor() as cursor:
                 await cursor.execute(sql, param)
                 rowcount = cursor.rowcount
@@ -42,7 +42,7 @@ class PostgresqlHelper(RelationalDbHelper):
         :param param:
         :return:
         """
-        async with self.pool.connection() as conn:
+        async with self.pool.acquire() as conn:
             async with conn.cursor() as cursor:
                 # 执行sql 传入参数
                 await cursor.executemany(sql, [tuple(item.values()) for item in param])
@@ -56,14 +56,14 @@ class PostgresqlHelper(RelationalDbHelper):
         :param param: 参数
         :return:
         """
-        async with self.pool.connection() as conn:
-            async with conn.cursor() as cursor:
+        async with self.pool.acquire() as conn:
+            async with conn.cursor() as cur:
                 if param:
-                    await cursor.execute(sql, param)
+                    await cur.execute(sql, param)
                 else:
-                    await cursor.execute(sql)
-                description = cursor.description
-                rs = await cursor.fetchone()
+                    await cur.execute(sql)
+                description = cur.description
+                rs = await cur.fetchone()
         return BaseSqlHelper.dict_row(description, rs)
 
     @echo_sql
@@ -74,11 +74,14 @@ class PostgresqlHelper(RelationalDbHelper):
         :param param: 参数
         :return:
         """
-        async with self.pool.connection() as conn:
-            async with conn.cursor() as cursor:
-                await cursor.execute(sql, param)
-                description = cursor.description
-                rs = await cursor.fetchall()
+        async with self.pool.acquire() as conn:
+            async with conn.cursor() as cur:
+                if param:
+                    await cur.execute(sql, param)
+                else:
+                    await cur.execute(sql)
+                description = cur.description
+                rs = await cur.fetchall()
         return BaseSqlHelper.dict_row(description, rs)
 
     def prepare_page_sql(self, condition_wrapper: ConditionWrapper, page_num: int, page_size: int):
