@@ -38,7 +38,72 @@ class BaseHandler(RequestHandler):
         重写父类get请求处理方法，直接调用post方法统一处理
         :return:
         """
-        await self.request_handler()
+        # 通过url路径获取对应的处理方法
+        res = [item for item in RouterMapping.instance().handlerMapping
+               if item[0] == self.request.path]
+        if res:
+            # 元组中索引0 存放url，索引 1 存放处理方法对象，此处获取方法对象
+            handler_method = res[0][1]
+            # 最终整理后的请求参数集合
+            params_list = []
+            # 获取当前请求的Content-Type
+            content_type = self.request.headers.get('Content-Type')
+            # 当前请求参数
+            arguments = self.request.arguments
+            # 如果当前请求contentType为application/json 需要对request.body进行JSON字符串转换
+            body_arguments = self.request.body
+            if body_arguments:
+                # 获取body 对象并把byte转为str
+                body_arguments = body_arguments.decode()
+                # 将json字符串转换为json对象 并加入到 请求参数字典中
+                arguments.update(json.loads(body_arguments))
+            # 获取处理方法的 参数签名
+            signature = inspect.signature(handler_method)
+            # parameterName 参数名称, parameter 参数对象
+            for parameter_name, parameter in signature.parameters.items():
+                # 如果参数是self 做特殊处理，传入本身
+                if parameter_name == 'self':
+                    params_list.append(self)
+                else:
+                    # 依据参数名称，获取请求参数值
+                    argument_value = arguments.get(parameter_name)
+                    # 分以下几种情况，第一种情况 未取得请求参数
+                    if argument_value is None:
+                        # 查看是否有默认值，如果有直接跳过即可
+                        if parameter.default is not inspect.Parameter.empty:
+                            params_list.append(parameter.default)
+                            continue
+                        else:
+                            # 如果没有有默认值，要抛出异常 提示"请求缺少必要参数"
+                            raise BusinessException(StatusCode.REQUIRED_PARAM_IS_EMPTY(parameter_name))
+                    # 获取形参类型
+                    parameter_type = parameter.annotation
+                    # 形参类型为空，尝试获取形参默认值类型
+                    if parameter_type is inspect.Parameter.empty:
+                        # if parameter.default is inspect.Parameter.empty:
+                        #     parameter_type = type(parameter.default)
+                        # else:
+                        parameter_type = type(parameter.default)
+                    # # 获取实参类型
+                    # argument_type = type(argument_value)
+                    if isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
+                        # 仅一个 直接存入
+                        if len(argument_value) == 1:
+                            params_list.append(parse_val(argument_value[0], parameter_type))
+                        else:  # 多个要使用集合存入
+                            params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                    else:
+                        params_list.append(parse_val(argument_value, parameter_type))
+            # 判断是否为异步非阻塞方法，true 则直接调用
+            if inspect.iscoroutinefunction(handler_method):
+                data = await handler_method(*params_list)
+            else:
+                # 阻塞方法异步调用
+                data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
+            if data:
+                self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
+        else:
+            raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
     async def post(self):
         """
@@ -110,10 +175,11 @@ class BaseHandler(RequestHandler):
                     # argument_type = type(argument_value)
                     if isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
                         # 仅一个 直接存入
-                        if len(argument_value) == 1:
-                            params_list.append(parse_val(argument_value[0], parameter_type))
-                        else:  # 多个要使用集合存入
-                            params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                        # if len(argument_value) == 1:
+                        #     params_list.append(parse_val(argument_value[0], parameter_type))
+                        # else:  # 多个要使用集合存入
+                        #     params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                        params_list.append([parse_val(v, parameter_type) for v in argument_value])
                     else:
                         params_list.append(parse_val(argument_value, parameter_type))
             # 判断是否为异步非阻塞方法，true 则直接调用
